@@ -8,7 +8,8 @@ if (!require(mvtnorm))
 gctorture(on = GCtorture)
 
 ### get rid of the NAMESPACE
-load(file.path(.find.package("party"), "R", "all.rda"))
+nsparty <- attach(NULL, name="ns-party")
+.Internal(lib.fixup(asNamespace("party"), nsparty))
 
 ### 
 ###
